{% extends 'timeseer.html' %}

{% from 'help.html' import help_menu with context %}

{% block styles %}
<style>
    h2, h3, h4 {
        margin-top: 0.5em;
    }

    #toctitle {
        font-weight: bold;
    }
    .imageblock {
        margin-bottom: 1rem;
    }
    .imageblock img {
        max-width: 100%;
    }
</style>
{% endblock %}


{% block menu %}
{{ help_menu('Admin documentation') }}
{% endblock %}

{% block main %}
<div class="ts-section py-3 my-3">
    <h2 class="h4">Admin documentation</h2>
</div>

<div class="my-3 py-3">
    {% include 'docs/' + page + '.html' %}
</div>
{% endblock %}
