{% from 'macros.html' import menu, visualize_series_name %}

{% macro prepare_menu(active) %}
{{
    menu(
        'Time series',
        [
            ('Metadata', url_for('prepare.tags', seriesid=series.series_id)),
            ('Statistics', url_for('prepare.show_statistics', seriesid=series.series_id)),
            ('Checks', url_for('prepare.show_checks', seriesid=series.series_id)),
            ('Event frames', url_for('prepare.show_event_frames', seriesid=series.series_id)),
            ('Chart', url_for('prepare.chart', seriesid=series.series_id)),
            ('Exports', url_for('prepare.exports', seriesid=series.series_id)),
            ('History', url_for('prepare.history', seriesid=series.series_id)),
        ],
        active,
    )
}}
{% endmacro %}
