{% extends 'timeseer.html' %}

{% from 'macros.html' import alerter, menu_back %}

{% block menu %}
{{ menu_back(url_for('.configure_data_service', dataservicename=data_service.name, sourcename=source_name)) }}
{% endblock %}

{% block main %}
<div class="ts-section py-3 my-3">
    <h2 class="h4">Rename {{ data_service.name }}</h2>
</div>

<div class="pt-3 my-3">
    {{ alerter() }}

    <form method="POST">
        <input type="hidden" name="dataservicename" value="{{ data_service.name }}">

        <div class="row mb-3">
            <label for="kpiSetNameInput" class="col-sm-2 col-form-label">New name</label>
            <div class="col-sm-10">
                <input type="text"
                        class="form-control"
                        id="dataServiceNameInput"
                        name="new_dataservicename"
                        value="{{ new_data_service_name }}"
                        required>
            </div>
        </div>

        <div class="btn-toolbar">
            <button type="submit" class="btn btn-primary me-2">Rename</button>
            <a class="btn btn-secondary"
                href="{{ url_for('.configure_data_service', dataservicename=data_service.name, sourcename=source_name) }}"
                role="button">
                Cancel
            </a>
        </div>
    </form>
</div>
{% endblock %}
