{% macro flows_header(flow_evaluation, title) %}
<div class="ts-section py-3 my-3">
    <div class="row align-items-center">
        <div class="col">
            <h2 class="h4">
                {{ title }}
            </h2>
            <p class="h6">
                <a href="{{ url_for('flows.list_series', flowevaluationid=flow_evaluation.db_id, sourcename=source_name) }}">{{ flow_evaluation.series_set_name }}</a> ({{ flow_evaluation.group.flow.name }})
            </p>
            <p class="text-muted">
                {% if flow_evaluation.group.time_range.has_no_time_range() is true %}
                -
                {% else %}
                From {{ flow_evaluation.group.time_range.start_date|datetimeformat }} to {{ flow_evaluation.group.time_range.end_date|datetimeformat }}
                {% endif %}
            </p>
        </div>
        {% if caller is defined %}
        <div class="col-lg-auto">
            {{ caller() }}
        </div>
        {% endif %}
    </div>
</div>
{% endmacro %}
