{% from 'macros.html' import menu, visualize_series_name %}

{% macro series_menu(active) %}
{{
    menu(
        (bootstrap_icon('arrow-left', 'h5 fw-bolder m-0', 24), back_url),
        [
            ('Metadata', url_for('flow_univariate.display_series', seriesid=series.series_id, blockevaluationid=block_evaluation.db_id)),
            ('Statistics', url_for('flow_univariate.show_statistics', seriesid=series.series_id, blockevaluationid=block_evaluation.db_id)),
            ('Checks', url_for('flow_univariate.show_checks', seriesid=series.series_id, blockevaluationid=block_evaluation.db_id)),
            ('Event frames', url_for('flow_univariate.show_event_frames', seriesid=series.series_id, blockevaluationid=block_evaluation.db_id)),
            ('Chart', url_for('flow_univariate.chart', seriesid=series.series_id, blockevaluationid=block_evaluation.db_id)),
            ('Exports', url_for('flow_univariate.series_exports', seriesid=series.series_id, blockevaluationid=block_evaluation.db_id)),
            ('History', url_for('flow_univariate.history', seriesid=series.series_id, blockevaluationid=block_evaluation.db_id)),
        ],
        active,
    )
}}
{% endmacro %}
