{% from 'macros.html' import bootstrap_icon, menu %}

{% macro flow_menu(active) %}
{{
menu(
    (bootstrap_icon('arrow-left', 'h5 fw-bolder m-0', 24), url_for('.display_dashboard', blockevaluationid=block_evaluation.db_id, sourcename=source_name)),
    kpi_references + [('Time series', url_for('.series_score_report', blockevaluationid=block_evaluation.db_id, sourcename=source_name))],
    active,
)
}}
{% endmacro %}
